@@ -1,14 +1,11 @@
 """Resource class containing all logic for creating, checking, and updating resources."""
 import datetime
 import logging
-from os import remove
 from os.path import join
 from pathlib import Path
 from typing import Any, Dict, List, Optional, Tuple, Union
 
 from hdx.utilities.downloader import Download
-from hdx.utilities.loader import load_json, load_yaml
-from hdx.utilities.path import script_dir_plus_file
 from hdx.utilities.uuid import is_valid_uuid
 
 import hdx.data.dataset
@@ -56,9 +53,6 @@ class Resource(HDXObject):
             "delete": "resource_delete",
             "search": "resource_search",
             "datastore_delete": "datastore_delete",
-            "datastore_create": "datastore_create",
-            "datastore_insert": "datastore_insert",
-            "datastore_upsert": "datastore_upsert",
             "datastore_search": "datastore_search",
         }
 
@@ -528,258 +522,6 @@ class Resource(HDXObject):
         if not success:
             logger.debug(result)
 
-    def create_datastore(
-        self,
-        schema: Optional[List[Dict]] = None,
-        primary_key: Optional[str] = None,
-        delete_first: int = 0,
-        path: Optional[str] = None,
-    ) -> None:
-        """For tabular data, create a resource in the HDX datastore which enables data preview in HDX. If no schema is provided
-        all fields are assumed to be text. If path is not supplied, the file is first downloaded from HDX.
-
-        Args:
-            schema (List[Dict]): List of fields and types of form {'id': 'FIELD', 'type': 'TYPE'}. Defaults to None.
-            primary_key (Optional[str]): Primary key of schema. Defaults to None.
-            delete_first (int): Delete datastore before creation. 0 = No, 1 = Yes, 2 = If no primary key. Defaults to 0.
-            path (Optional[str]): Local path to file that was uploaded. Defaults to None.
-
-        Returns:
-            None
-        """
-        if delete_first == 0:
-            pass
-        elif delete_first == 1:
-            self.delete_datastore()
-        elif delete_first == 2:
-            if primary_key is None:
-                self.delete_datastore()
-        else:
-            raise HDXError(
-                "delete_first must be 0, 1 or 2! (0 = No, 1 = Yes, 2 = Delete if no primary key)"
-            )
-        if path is None:
-            # Download the resource
-            url, path = self.download()
-            delete_after_download = True
-        else:
-            url = path
-            delete_after_download = False
-
-        def convert_to_text(extended_rows):
-            for number, headers, row in extended_rows:
-                for i, val in enumerate(row):
-                    row[i] = str(val)
-                yield (number, headers, row)
-
-        with Download(
-            full_agent=self.configuration.get_user_agent()
-        ) as downloader:
-            try:
-                stream = downloader.get_tabular_stream(
-                    path,
-                    headers=1,
-                    post_parse=[convert_to_text],
-                    bytes_sample_size=1000000,
-                )
-                nonefieldname = False
-                if schema is None:
-                    schema = list()
-                    for fieldname in stream.headers:
-                        if fieldname is not None:
-                            schema.append({"id": fieldname, "type": "text"})
-                        else:
-                            nonefieldname = True
-                data = {
-                    "resource_id": self.data["id"],
-                    "force": True,
-                    "fields": schema,
-                    "primary_key": primary_key,
-                }
-                self._write_to_hdx("datastore_create", data, "resource_id")
-                if primary_key is None:
-                    method = "insert"
-                else:
-                    method = "upsert"
-                logger.debug(f"Uploading data from {url} to datastore")
-                offset = 0
-                chunksize = 100
-                rowset = stream.read(keyed=True, limit=chunksize)
-                while len(rowset) != 0:
-                    if nonefieldname:
-                        for row in rowset:
-                            del row[None]
-                    data = {
-                        "resource_id": self.data["id"],
-                        "force": True,
-                        "method": method,
-                        "records": rowset,
-                    }
-                    self._write_to_hdx("datastore_upsert", data, "resource_id")
-                    rowset = stream.read(keyed=True, limit=chunksize)
-                    logger.debug(f"Uploading: {offset}")
-                    offset += chunksize
-            except Exception as e:
-                raise HDXError(f"Upload to datastore of {url} failed!") from e
-            finally:
-                if delete_after_download:
-                    remove(path)
-
-    def create_datastore_from_dict_schema(
-        self, data: dict, delete_first: int = 0, path: Optional[str] = None
-    ) -> None:
-        """For tabular data, create a resource in the HDX datastore which enables data preview in HDX from a dictionary
-        containing a list of fields and types of form {'id': 'FIELD', 'type': 'TYPE'} and optionally a primary key.
-        If path is not supplied, the file is first downloaded from HDX.
-
-        Args:
-            data (dict): Dictionary containing list of fields and types of form {'id': 'FIELD', 'type': 'TYPE'}
-            delete_first (int): Delete datastore before creation. 0 = No, 1 = Yes, 2 = If no primary key. Defaults to 0.
-            path (Optional[str]): Local path to file that was uploaded. Defaults to None.
-
-        Returns:
-            None
-        """
-        schema = data["schema"]
-        primary_key = data.get("primary_key")
-        self.create_datastore(schema, primary_key, delete_first, path=path)
-
-    def create_datastore_from_yaml_schema(
-        self,
-        yaml_path: str,
-        delete_first: Optional[int] = 0,
-        path: Optional[str] = None,
-    ) -> None:
-        """For tabular data, create a resource in the HDX datastore which enables data preview in HDX from a YAML file
-        containing a list of fields and types of form {'id': 'FIELD', 'type': 'TYPE'} and optionally a primary key.
-        If path is not supplied, the file is first downloaded from HDX.
-
-        Args:
-            yaml_path (str): Path to YAML file containing list of fields and types of form {'id': 'FIELD', 'type': 'TYPE'}
-            delete_first (int): Delete datastore before creation. 0 = No, 1 = Yes, 2 = If no primary key. Defaults to 0.
-            path (Optional[str]): Local path to file that was uploaded. Defaults to None.
-
-        Returns:
-            None
-        """
-        data = load_yaml(yaml_path)
-        self.create_datastore_from_dict_schema(data, delete_first, path=path)
-
-    def create_datastore_from_json_schema(
-        self, json_path: str, delete_first: int = 0, path: Optional[str] = None
-    ) -> None:
-        """For tabular data, create a resource in the HDX datastore which enables data preview in HDX from a JSON file
-        containing a list of fields and types of form {'id': 'FIELD', 'type': 'TYPE'} and optionally a primary key.
-        If path is not supplied, the file is first downloaded from HDX.
-
-        Args:
-            json_path (str): Path to JSON file containing list of fields and types of form {'id': 'FIELD', 'type': 'TYPE'}
-            delete_first (int): Delete datastore before creation. 0 = No, 1 = Yes, 2 = If no primary key. Defaults to 0.
-            path (Optional[str]): Local path to file that was uploaded. Defaults to None.
-
-        Returns:
-            None
-        """
-        data = load_json(json_path)
-        self.create_datastore_from_dict_schema(data, delete_first, path=path)
-
-    def create_datastore_for_topline(
-        self, delete_first: int = 0, path: Optional[str] = None
-    ) -> None:
-        """For tabular data, create a resource in the HDX datastore which enables data preview in HDX using the built in
-        YAML definition for a topline. If path is not supplied, the file is first downloaded from HDX.
-
-        Args:
-            delete_first (int): Delete datastore before creation. 0 = No, 1 = Yes, 2 = If no primary key. Defaults to 0.
-            path (Optional[str]): Local path to file that was uploaded. Defaults to None.
-
-        Returns:
-            None
-        """
-        data = load_yaml(
-            script_dir_plus_file("hdx_datasource_topline.yml", Resource)
-        )
-        self.create_datastore_from_dict_schema(data, delete_first, path=path)
-
-    def update_datastore(
-        self,
-        schema: Optional[List[Dict]] = None,
-        primary_key: Optional[str] = None,
-        path: Optional[str] = None,
-    ) -> None:
-        """For tabular data, update a resource in the HDX datastore which enables data preview in HDX. If no schema is provided
-        all fields are assumed to be text. If path is not supplied, the file is first downloaded from HDX.
-
-        Args:
-            schema (List[Dict]): List of fields and types of form {'id': 'FIELD', 'type': 'TYPE'}. Defaults to None.
-            primary_key (Optional[str]): Primary key of schema. Defaults to None.
-            path (Optional[str]): Local path to file that was uploaded. Defaults to None.
-
-        Returns:
-            None
-        """
-        self.create_datastore(schema, primary_key, 2, path=path)
-
-    def update_datastore_from_dict_schema(
-        self, data: dict, path: Optional[str] = None
-    ) -> None:
-        """For tabular data, update a resource in the HDX datastore which enables data preview in HDX from a dictionary
-        containing a list of fields and types of form {'id': 'FIELD', 'type': 'TYPE'} and optionally a primary key.
-        If path is not supplied, the file is first downloaded from HDX.
-
-        Args:
-            data (dict): Dictionary containing list of fields and types of form {'id': 'FIELD', 'type': 'TYPE'}
-            path (Optional[str]): Local path to file that was uploaded. Defaults to None.
-
-        Returns:
-            None
-        """
-        self.create_datastore_from_dict_schema(data, 2, path=path)
-
-    def update_datastore_from_yaml_schema(
-        self, yaml_path: str, path: Optional[str] = None
-    ) -> None:
-        """For tabular data, update a resource in the HDX datastore which enables data preview in HDX from a YAML file
-        containing a list of fields and types of form {'id': 'FIELD', 'type': 'TYPE'} and optionally a primary key.
-        If path is not supplied, the file is first downloaded from HDX.
-
-        Args:
-            yaml_path (str): Path to YAML file containing list of fields and types of form {'id': 'FIELD', 'type': 'TYPE'}
-            path (Optional[str]): Local path to file that was uploaded. Defaults to None.
-
-        Returns:
-            None
-        """
-        self.create_datastore_from_yaml_schema(yaml_path, 2, path=path)
-
-    def update_datastore_from_json_schema(
-        self, json_path: str, path: Optional[str] = None
-    ) -> None:
-        """For tabular data, update a resource in the HDX datastore which enables data preview in HDX from a JSON file
-        containing a list of fields and types of form {'id': 'FIELD', 'type': 'TYPE'} and optionally a primary key.
-        If path is not supplied, the file is first downloaded from HDX.
-
-        Args:
-            json_path (str): Path to JSON file containing list of fields and types of form {'id': 'FIELD', 'type': 'TYPE'}
-            path (Optional[str]): Local path to file that was uploaded. Defaults to None.
-
-        Returns:
-            None
-        """
-        self.create_datastore_from_json_schema(json_path, 2, path=path)
-
-    def update_datastore_for_topline(self, path: Optional[str] = None) -> None:
-        """For tabular data, update a resource in the HDX datastore which enables data preview in HDX using the built in YAML
-        definition for a topline. If path is not supplied, the file is first downloaded from HDX.
-
-        Args:
-            path (Optional[str]): Local path to file that was uploaded. Defaults to None.
-
-        Returns:
-            None
-        """
-        self.create_datastore_for_topline(2, path=path)
-
     def get_resource_views(self) -> List[ResourceView]:
         """Get any resource views in the resource
 
